==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkMenuPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 66ac9ea9a2d96b15 gnu_java_awt_peer_gtk_GtkMenuPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuItemPeer

#include "gnu/java/awt/peer/gtk/GtkMenuItemPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;
struct _jc_java_awt_Menu$object;
struct _jc_java_awt_MenuItem$object;
struct _jc_java_awt_MenuShortcut$object;
struct _jc_java_awt_peer_MenuItemPeer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$_init$48d28cc4c2e5f9e0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_Menu$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$34639f0f3827815e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_MenuItem$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$b50196a328c75b84(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, jint, jboolean);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$1f8a5c0b49f06741(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, struct _jc_java_awt_MenuShortcut$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addTearOff$dc2df79ce7fc70f1(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$create$7b5006c0217fdf3e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$delItem$5ab882e05042bf6f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$setupAccelGroup$a19fe7bfa46a7d2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$34639f0f3827815e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$b50196a328c75b84;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$1f8a5c0b49f06741;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addTearOff$dc2df79ce7fc70f1;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$create$7b5006c0217fdf3e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$delItem$5ab882e05042bf6f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$setupAccelGroup$a19fe7bfa46a7d2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods {
	void	(*addItem$34639f0f3827815e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_MenuItem$object *);
	void	(*addItem$b50196a328c75b84)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, jint, jboolean);
	void	(*addItem$1f8a5c0b49f06741)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, struct _jc_java_awt_MenuShortcut$object *);
	void	(*addTearOff$dc2df79ce7fc70f1)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *);
	void	(*create$7b5006c0217fdf3e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_lang_String$object *);
	void	(*delItem$5ab882e05042bf6f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, jint);
	void	(*setupAccelGroup$a19fe7bfa46a7d2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkMenuPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 66ac9ea9a2d96b15 gnu_java_awt_peer_gtk_GtkMenuPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuItemPeer

#include "gnu/java/awt/peer/gtk/GtkMenuItemPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;
struct _jc_java_awt_Menu$object;
struct _jc_java_awt_MenuItem$object;
struct _jc_java_awt_MenuShortcut$object;
struct _jc_java_awt_peer_MenuItemPeer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$_init$48d28cc4c2e5f9e0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_Menu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$34639f0f3827815e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_MenuItem$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$b50196a328c75b84(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addItem$1f8a5c0b49f06741(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, struct _jc_java_awt_MenuShortcut$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$addTearOff$dc2df79ce7fc70f1(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$create$7b5006c0217fdf3e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$delItem$5ab882e05042bf6f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method$setupAccelGroup$a19fe7bfa46a7d2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$34639f0f3827815e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$b50196a328c75b84;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addItem$1f8a5c0b49f06741;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$addTearOff$dc2df79ce7fc70f1;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$create$7b5006c0217fdf3e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$delItem$5ab882e05042bf6f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$method_info$setupAccelGroup$a19fe7bfa46a7d2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods {
	void	(*addItem$34639f0f3827815e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_awt_MenuItem$object *) _JC_JCNI_ATTR;
	void	(*addItem$b50196a328c75b84)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, jint, jboolean) _JC_JCNI_ATTR;
	void	(*addItem$1f8a5c0b49f06741)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_object *, struct _jc_java_awt_MenuShortcut$object *) _JC_JCNI_ATTR;
	void	(*addTearOff$dc2df79ce7fc70f1)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *) _JC_JCNI_ATTR;
	void	(*create$7b5006c0217fdf3e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*delItem$5ab882e05042bf6f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*setupAccelGroup$a19fe7bfa46a7d2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuPeer_H_ */
